///////////////////////////////////////////////////////////////////////////////
// Name:        templates.cpp
// Purpose:     Demonstration of rotation in wxPdfDocument
// Author:      Ulrich Telle
// Modified by:
// Created:     2005-08-29
// Copyright:   (c) Ulrich Telle
// Licence:     wxWindows licence
///////////////////////////////////////////////////////////////////////////////

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#ifndef WX_PRECOMP
#include "wx/wx.h"
#endif

#include "wx/wxpdf/pdfdoc.h"

/**
* Templates
*
* This example shows the creation and use of templates.
*/

void templates()
{
  int i;
  double w, h;
  int tpl1, tpl2;
  wxPdfDocument pdf;

  pdf.AddPage();
pdf.SetCompression(false);
  // Generate a template clip on  x=0, y=0, width=180, height=350
  // Take care, that the margins of the Template are setted to the
  // original-margins.
  tpl1 = pdf.BeginTemplate(0, 0, 180, 350);
  pdf.SetFont(_T("Arial"), _T(""), 14);
  pdf.SetTextColor(0);
  for(i = 0; i < 200; i++)
  {
    pdf.Write(10, wxString::Format(_T("dummy text %d "), i));
  }
  pdf.Image(_T("glasses.png"), 100, 60, 100);
  pdf.EndTemplate();

  // Generate a template that will hold the whole page
  tpl2 = pdf.BeginTemplate();
  pdf.SetFont(_T("Arial"), _T(""), 14);

  // demonstrate how to lay text in background of an existing template
  pdf.SetXY(115, 55);
  pdf.Write(10, _T("write behind it..."));

  // Now we use our first created template on position x=10, y=10 and
  // give it a width of 50mm (height is calculated automaticaly) and draw a border around it
  pdf.UseTemplate(tpl1, 10, 10, 50);
  w = 50;
  h = 0;
  pdf.GetTemplateSize(tpl1, w, h);
  pdf.Rect(10, 10, w, h);

  // Same as above, but another size
  pdf.UseTemplate(tpl1, 70, 10, 100);
  w = 100;
  h = 0;
  pdf.GetTemplateSize(tpl1, w, h);
  pdf.Rect(70, 10, w, h);
  pdf.EndTemplate();

  // Till now, there is no output to the PDF-File
  // We draw Template No. 2, that includes 2 Versions of the first
  pdf.UseTemplate(tpl2);

  pdf.AddPage();

  // Here we reuse Template No. 2
  // For example I used the rotate-script
  // to show u how, easy it is to use the created templates
  pdf.SetFillColor(255);
  for (i = 90; i >= 0; i -= 30)
  {
    pdf.StartTransform();
    pdf.Rotate(i, 10, 120);
    w = 100;
    h = 0;
    pdf.GetTemplateSize(tpl2, w, h);
    pdf.Rect(10, 120, w, h, wxPDF_STYLE_FILLDRAW);
    pdf.UseTemplate(tpl2, 10, 120, 100);
    pdf.StopTransform();
  }

  pdf.SaveAsFile(_T("templates.pdf"));
}
